@@ -40,10 +40,12 @@
 #include <gtkmm/toolbar.h>
 #include <gtkmm/treemodel.h>
 #include <boost/shared_ptr.hpp>
+#include <libglademm.h>
 
 #include "core/gcs-types.h"
 #include "widgets/gcs-paletteview.h"
 
+using namespace Gnome;
 
 namespace gcs
 {
@@ -65,16 +67,18 @@ namespace gcs
     class MainWindow : public Gtk::Window
     {
         public:
+            MainWindow(GtkWindow *cobject, Glib::RefPtr<Glade::Xml>& refGlade);
             ~MainWindow(void);
 
             static MainWindow& Instance();
             void set_color(ColorPtr c);
 
         protected:
-            MainWindow(void);
             // no copying allowed
             MainWindow(MainWindow& w);
 
+            virtual void on_realize();
+
             // setup functions
             void init_actions(void);
             void init_ui(void);
@@ -124,7 +128,6 @@ namespace gcs
             gint rand_range(gint range);
 
             /* swatch popup menu */
-            void on_menu_file_popup_generic(void);
             void on_action_use_color(void);
 
             void on_bookmarks_selection_changed(void);
@@ -136,44 +139,40 @@ namespace gcs
                     guint time);
 
         private:
+            Glib::RefPtr<Glade::Xml> m_glade;
             static MainWindow *m_instance;
             // for creating menus and toolbars
             Glib::RefPtr<Gtk::UIManager> m_refUIManager;
             Glib::RefPtr<Gtk::ActionGroup> m_refActionGroup;
 
             // Containers for layout
-            Gtk::VBox *m_pLayout;
-            Gtk::HBox *m_pInnerLayout;
-            Gtk::VBox *m_pSchemeColumn;
-            Gtk::ScrolledWindow *m_pScrollBox;
-            Gtk::VBox *m_pBookmarkColumn;
-            Gtk::HPaned *m_pPane;
-            Gtk::HBox *m_pControls;
+            Gtk::VBox *m_vbox_layout;
+            Gtk::VBox *m_vbox_menu_toolbar;
+            Gtk::VBox *m_vbox_main;
+            Gtk::VBox *m_vbox_favorites;
+            Gtk::VBox *m_scrolledwindow_favorites;
+            Gtk::VBox *m_vbox_scheme_display;
+            Gtk::HPaned *m_pane;
 
             // Menus and Toolbars
-            Gtk::Menu *m_pMainMenu;
-            Gtk::Toolbar *m_pTweakBar;
-            Gtk::Toolbar *m_pBookmarkBar;
+            Gtk::Menu *m_main_menu;
+            Gtk::Toolbar *m_toolbar;
+            Gtk::Toolbar *m_bookmark_bar;
 
-            Gtk::ColorButton *m_pColorButton;
-            Widgets::SchemeSelector *m_pSchemeSelector;
-            Widgets::SchemeBox *m_pSchemeBox;
-            Widgets::BookmarkList *m_pBookmarkList;
-            Widgets::PaletteView* m_PaletteView;
+            Gtk::ColorButton *m_color_button;
+            Widgets::SchemeSelector *m_scheme_selector;
+            Widgets::SchemeBox *m_scheme_box;
+            Widgets::BookmarkList *m_bookmark_list;
+            Widgets::PaletteView* m_palette_view;
             Glib::ustring m_palette_file;
-            Glib::ustring m_bookmarks_file;
 
-            Gtk::Statusbar *m_pStatusbar;
+            Gtk::Statusbar *m_statusbar;
 
             Dialogs::AboutWindow *m_pAbout;
 
             // NON-UI ELEMENTS
             HistoryNavigation<Glib::ustring> *m_pHistory;
 
-            static const gint WINDOW_HEIGHT;
-            static const gint WINDOW_WIDTH;
-            static const gint FAVORITES_WIDTH;
-
             friend void clipboard_owner_changed(GtkClipboard* clipboard, GdkEvent* event, gpointer data);
     };
 
