@@ -46,19 +46,19 @@ namespace gcs
 {
     namespace Widgets
     {
-        BookmarkList::BookmarkList(Glib::ustring fname) :
-            m_file(fname),
+        BookmarkList::BookmarkList() :
+            m_file(Conf::get_favorites_file()),
             m_refUIManager(Gtk::UIManager::create())
         {
-            LOG("Populating favorites: " << fname);
-            std::ifstream file(fname.c_str());
+            LOG("Populating favorites: " << m_file);
+            std::ifstream file(m_file.c_str());
             try
             {
                 m_palette.parse(file);
             }
             catch (const pp::ParseError& e)
             {
-                g_warning("%s: %s", fname.c_str(), e.what());
+                g_warning("%s: %s", m_file.c_str(), e.what());
             }
             m_refPaletteModel = PaletteTreeModel::create(m_palette);
             set_model(m_refPaletteModel);
